@@ -1,14 +1,16 @@
 import logging
+
 from torch.utils.data import Dataset
 
+
 class CachedDataset(Dataset):
     def __init__(self, dataset, transform=None):
         self.logger = logging.getLogger(type(self).__name__)
         self.dataset = dataset
         self.transform = transform
 
-    def __getitem__(self, index):
-        sample = self._getitem_impl(index)
+    def __getitem__(self, idx):
+        sample = self._cached_getitem(idx)
         if self.transform is not None:
             sample = self.transform(sample)
         return sample
@@ -21,8 +23,8 @@ class CachedDataset(Dataset):
             return getattr(super(), item)
         return getattr(self.dataset, item)
 
-    def _getitem_impl(self, index):
+    def _cached_getitem(self, index):
         raise NotImplementedError
 
     def dispose(self):
-        raise NotImplementedError
\ No newline at end of file
+        raise NotImplementedError
