@@ -1,9 +1,8 @@
 import kappadata.common.wrappers.sample_wrappers
 # sample wrappers
 from .sample_wrappers import (
-    BYOLMultiViewWrapper,
+    ByolMultiViewWrapper,
     ImagenetMinaugMultiViewWrapper,
     ImagenetMinaugXTransformWrapper,
     ImagenetNoaugXTransformWrapper,
 )
-
